import TreeBaseContainer from './Base/TreeBaseContainer';
import { initContainer } from "../ContainerBase/index";
import TreeIterator from './Base/TreeIterator';
export declare class OrderedSetIterator<K> extends TreeIterator<K, undefined> {
    get pointer(): K;
    copy(): OrderedSetIterator<K>;
}
declare class OrderedSet<K> extends TreeBaseContainer<K, undefined> {
    constructor(container?: initContainer<K>, cmp?: (x: K, y: K) => number);
    private readonly iterationFunc;
    begin(): OrderedSetIterator<K>;
    end(): OrderedSetIterator<K>;
    rBegin(): OrderedSetIterator<K>;
    rEnd(): OrderedSetIterator<K>;
    front(): K | undefined;
    back(): K | undefined;
    forEach(callback: (element: K, index: number) => void): void;
    getElementByPos(pos: number): K;
    /**
     * @description Insert element to set.
     * @param key The key want to insert.
     * @param hint You can give an iterator hint to improve insertion efficiency.
     */
    insert(key: K, hint?: OrderedSetIterator<K>): void;
    find(element: K): OrderedSetIterator<K>;
    /**
     * @return An iterator to the first element not less than the given key.
     */
    lowerBound(key: K): OrderedSetIterator<K>;
    /**
     * @return An iterator to the first element greater than the given key.
     */
    upperBound(key: K): OrderedSetIterator<K>;
    /**
     * @return An iterator to the first element not greater than the given key.
     */
    reverseLowerBound(key: K): OrderedSetIterator<K>;
    /**
     * @return An iterator to the first element less than the given key.
     */
    reverseUpperBound(key: K): OrderedSetIterator<K>;
    /**
     * @description Union the other Set to self.
     *              <br/>
     *              Waiting for optimization, this is O(mlog(n+m)) algorithm now,
     *              but we expect it to be O(mlog(n/m+1)).<br/>
     *              More information =>
     *              https://en.wikipedia.org/wiki/Red_black_tree
     *              <br/>
     * @param other The other set you want to merge.
     */
    union(other: OrderedSet<K>): void;
    [Symbol.iterator](): Generator<K, void, undefined>;
}
export default OrderedSet;
